==> haskell-hls-graph-1.4.0.0-30-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-graph.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-graph
version:              1.4.0.0
visibility:           public
id:                   hls-graph-1.4.0.0-AjwdVLwrWsFIph05OFw9MP
key:                  hls-graph-1.4.0.0-AjwdVLwrWsFIph05OFw9MP
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             Haskell Language Server internal graph API
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  b70589555e8f8bc922ea3a2f6d96740b
exposed:              True
exposed-modules:
    Development.IDE.Graph Development.IDE.Graph.Classes
    Development.IDE.Graph.Database Development.IDE.Graph.Rule

hidden-modules:
    Development.IDE.Graph.Internal.Action
    Development.IDE.Graph.Internal.Options
    Development.IDE.Graph.Internal.Rules

import-dirs:          /usr/lib/ghc-9.0.1/site-local/hls-graph-1.4.0.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/hls-graph-1.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/hls-graph-1.4.0.0
hs-libraries:         HShls-graph-1.4.0.0-AjwdVLwrWsFIph05OFw9MP
depends:
    base-4.15.0.0 bytestring-0.10.12.1
    shake-0.19.5-Fw5RZhz0W6F6YRaEiqQMrk
    unordered-containers-0.2.14.0-DBDZ3ZaaKWNDxQAlLFMrPR

haddock-interfaces:   /usr/share/doc/haskell-hls-graph/html/hls-graph.haddock
haddock-html:         /usr/share/doc/haskell-hls-graph/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-graph-1.4.0.0-34-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-graph.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hls-graph
version:              1.4.0.0
visibility:           public
id:                   hls-graph-1.4.0.0-2fc0H1yqXdoLMCwvMXkCmH
key:                  hls-graph-1.4.0.0-2fc0H1yqXdoLMCwvMXkCmH
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             Haskell Language Server internal graph API
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  d1c0c2ce6e637154fca87b0c9921055f
exposed:              True
exposed-modules:
    Development.IDE.Graph Development.IDE.Graph.Classes
    Development.IDE.Graph.Database Development.IDE.Graph.Rule

hidden-modules:
    Development.IDE.Graph.Internal.Action
    Development.IDE.Graph.Internal.Options
    Development.IDE.Graph.Internal.Rules

import-dirs:          /usr/lib/ghc-9.0.1/site-local/hls-graph-1.4.0.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/hls-graph-1.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/hls-graph-1.4.0.0
hs-libraries:         HShls-graph-1.4.0.0-2fc0H1yqXdoLMCwvMXkCmH
depends:
    base-4.15.0.0 bytestring-0.10.12.1
    shake-0.19.5-I9LpKlHqyBNFd2OYeZg9Af
    unordered-containers-0.2.14.0-DBDZ3ZaaKWNDxQAlLFMrPR

haddock-interfaces:   /usr/share/doc/haskell-hls-graph/html/hls-graph.haddock
haddock-html:         /usr/share/doc/haskell-hls-graph/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
